@@ -22,14 +22,11 @@
 
 #include "printstyle.h"
 
-namespace KAddressBookGrantlee
-{
+namespace KAddressBookGrantlee {
 class GrantleePrint;
 }
 
-namespace KABPrinting
-{
-
+namespace KABPrinting {
 class PrintProgress;
 
 class GrantleePrintStyle : public PrintStyle
@@ -40,7 +37,7 @@ public:
     explicit GrantleePrintStyle(const QString &themePath, PrintingWizard *parent);
     ~GrantleePrintStyle();
 
-    void print(const KContacts::Addressee::List &, PrintProgress *) Q_DECL_OVERRIDE;
+    void print(const KContacts::Addressee::List &, PrintProgress *) override;
 private:
     KAddressBookGrantlee::GrantleePrint *mGrantleePrint;
 };
@@ -50,13 +47,12 @@ class GrantleeStyleFactory : public PrintStyleFactory
 public:
     explicit GrantleeStyleFactory(const QString &name, const QString &themePath, PrintingWizard *parent);
 
-    PrintStyle *create() const Q_DECL_OVERRIDE;
-    QString description() const Q_DECL_OVERRIDE;
+    PrintStyle *create() const override;
+    QString description() const override;
 private:
     QString mThemePath;
     QString mName;
 };
-
 }
 
 #endif // GRANTLEEPRINTSTYLE_H
